# -*- coding: utf-8 -*-

"""Top-level package for PrettyQt."""

__author__ = """Philipp Temminghoff"""
__email__ = "phil65@kodi.tv"
__version__ = "0.63.0"


__all__ = ["core",
           "gui",
           "widgets",
           "custom_widgets",
           "custom_models",
           "syntaxhighlighters",
           "charts",
           "webenginewidgets"]
